=======
History
=======

0.5.5 (2019-02-13)
------------------

* bug fixes/improvements

0.5.4 (2019-02-12)
------------------

* fix --dump for absent files

0.5.3 (2019-02-12)
------------------

* allow dumping of env vars
* fixes for py2.x

0.5.2 (2019-01-27)
------------------

* allow skipping of env vars
* allow removal of env vars
* check for rate limit

0.5.1 (2019-01-08)
------------------

* fixes

0.5.0 (2019-01-06)
------------------

* Major revamp: Does not require Heroku CLI anymore. Uses Heroku API instead.
* Added --version/-v to check version
* Minor improvements

0.4.0 (2018-12-30)
------------------

* Detect Heroku installation and issues and launch appropriate URLs in browser to guide user
* Minor improvements

0.3.0 (2018-12-29)
------------------

* add feature to set alternate values during run
* cleanup and minor improvements

0.2.0 (2018-12-24)
------------------

* First release on PyPI.
